@@ -1,6 +1,6 @@
 # ----- pyloglib -----
 # Python Logging Library
-# v1.0.7
+# v1.0.8
 
 from datetime import datetime
 
@@ -8,14 +8,14 @@ class Log:
     def __init__(
         self, 
         prefix="", 
-        surfix="",
+        suffix="",
         splitter=" ",
         time=False,
         clock=True,
         saveprefix=True, 
         printprefix=True, 
-        savesurfix=True, 
-        printsurfix=True, 
+        savesuffix=True, 
+        printsuffix=True, 
         savetime=True, 
         printtime=True, 
         print=True, 
@@ -23,14 +23,14 @@ class Log:
         ):
 
         self.prefix = prefix
-        self.surfix = surfix
+        self.suffix = suffix
         self.splitter = splitter
         self.time = time
         self.clock = clock
         self.saveprefix = saveprefix
         self.printprefix = printprefix
-        self.savesurfix = savesurfix
-        self.printsurfix = printsurfix
+        self.savesuffix = savesuffix
+        self.printsuffix = printsuffix
         self.savetime = savetime
         self.printtime = printtime
         self.print = print
@@ -45,7 +45,7 @@ class Log:
                     self.loglist.append(i.replace('\n', ''))
         except: pass
 
-    def log(self, content, prefix=None, surfix=None, time=None):
+    def log(self, content, prefix=None, suffix=None, time=None):
         currenttime = str(datetime.date(datetime.now())).split("-")
         currenttime.reverse()
         if self.clock == True:
@@ -63,10 +63,10 @@ class Log:
                 printedlog = printedlog + f"{currenttime}"
             elif time == True: printedlog = printedlog + f"{currenttime}"
             printedlog = printedlog + f"{content}"
-            if surfix != None and self.printsurfix == True:
-                printedlog = printedlog + f"{surfix}"
-            elif self.printsurfix == True:
-                printedlog = printedlog + f"{self.surfix}"
+            if suffix != None and self.printsuffix == True:
+                printedlog = printedlog + f"{suffix}"
+            elif self.printsuffix == True:
+                printedlog = printedlog + f"{self.suffix}"
             print(printedlog)
         
         if self.file != None:
@@ -80,14 +80,14 @@ class Log:
                     savedlog = savedlog + f"{currenttime}"
                 elif time == True: savedlog = savedlog + f"{currenttime}"
                 savedlog = savedlog + f"{content}"
-                if surfix != None and self.savesurfix == True:
-                    savedlog = savedlog + f"{surfix}"
-                elif self.printsurfix == True:
-                    savedlog = savedlog + f"{self.surfix}"
+                if suffix != None and self.savesuffix == True:
+                    savedlog = savedlog + f"{suffix}"
+                elif self.printsuffix == True:
+                    savedlog = savedlog + f"{self.suffix}"
                 file.write(f"{savedlog}\n")
         
             self.loglist.append(savedlog)
-        return f"{self.prefix}{currenttime}{content}{self.surfix}"
+        return f"{self.prefix}{currenttime}{content}{self.suffix}"
 
     def logtitle(self, content):
 
