@@ -2,21 +2,21 @@ import pyloglib
 
 mylog = pyloglib.Log(
     prefix="",
-    surfix="",
+    suffix="",
     splitter=" ",
     time=False , 
     clock=True, 
     saveprefix=True, 
     printprefix=True, 
-    savesurfix=True, 
-    printsurfix=True, 
+    savesuffix=True, 
+    printsuffix=True, 
     savetime=True, 
     printtime=True, 
     print=True, 
     file=None
 )
 
-mylog.log("Hello World!", prefix=None, surfix=None, time=None)
+mylog.log("Hello World!", prefix=None, suffix=None, time=None)
 mylog.logtitle("Hello World!")
 mylog.lograw("Hello World!")
 
